@@ -19,7 +19,7 @@ from bwobject import BWObject
 from bwmethod import (before_super, after_super, follow_super, filter_super,
                       override_super, around_super, override_result)
 from bwcached import cached, classcached, cachedmethod
-from bwmember import member
+from bwmember import member, into
 from bwthrowable import throw, catch, BWThrowable, TC
 
 __doc__ += '\nCHANGELOG:\n\n' + str(CHANGELOG)
